@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="gl_ES">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
 <context>
     <name>Installer</name>
     <message>
@@ -17,25 +15,25 @@
     <message>
         <location filename="../installer.cpp" line="90"/>
         <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
-        <translation type="unfinished"></translation>
+        <translation>Os seguintes paquetes serán instalados. Fai clic en &apos;Mostrar detalles...&apos; para obter información sobre os paquetes.</translation>
     </message>
     <message>
         <location filename="../installer.cpp" line="98"/>
         <source>File: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ficheiro: %1</translation>
     </message>
     <message>
         <location filename="../installer.cpp" line="115"/>
         <source>Will install the following:</source>
-        <translation type="unfinished"></translation>
+        <translation>Instalará o seguinte:</translation>
     </message>
     <message>
         <location filename="../installer.cpp" line="130"/>
         <source>Installing selected package please authenticate</source>
-        <translation type="unfinished"></translation>
+        <translation>Instalando o paquete seleccionado, por favor autentíquese.</translation>
     </message>
     <message>
-        <location filename="../installer.cpp" line="136"/>
+        <location filename="../installer.cpp" line="135"/>
         <source>Press any key to close</source>
         <translation>Premer calquera tecla para pechar</translation>
     </message>
@@ -45,37 +43,37 @@
     <message>
         <location filename="../main.cpp" line="46"/>
         <source>Program for installing Debian binary packages (deb files)</source>
-        <translation type="unfinished"></translation>
+        <translation>Programa para instalar paquetes binarios de Debian (archivos deb)</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="49"/>
         <source>files...</source>
-        <translation type="unfinished"></translation>
+        <translation>arquivos...</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="49"/>
         <source>Name of .deb files to install</source>
-        <translation type="unfinished"></translation>
+        <translation>Nome dos ficheiros .deb para instalar</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="50"/>
         <source>[file...]</source>
-        <translation type="unfinished"></translation>
+        <translation>[ficheiro...]</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="72"/>
         <source>Select .deb files to install</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecciona os ficheiros .deb para instalar.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="73"/>
         <source>Deb Files (*.deb)</source>
-        <translation type="unfinished"></translation>
+        <translation>Deb Ficheiros (*.deb)</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="77"/>
         <source>No .deb files were provided.</source>
-        <translation type="unfinished"></translation>
+        <translation>Non se proporcionaron ficheiros .deb.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="84"/>
@@ -87,12 +85,12 @@
     <message>
         <location filename="../main.cpp" line="84"/>
         <source>File %1 not found</source>
-        <translation type="unfinished"></translation>
+        <translation>Ficheiro %1 non encontrado</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="89"/>
         <source>File %1 is not a .deb file.</source>
-        <translation type="unfinished"></translation>
+        <translation>O ficheiro %1 non é un ficheiro .deb.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="96"/>
@@ -100,4 +98,4 @@
         <translation>Dbeeb executar este programa como usuario normal.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
