@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
 <context>
     <name>Installer</name>
     <message>
@@ -35,7 +33,7 @@
         <translation>Installerar valt paket var vänlig verifiera</translation>
     </message>
     <message>
-        <location filename="../installer.cpp" line="136"/>
+        <location filename="../installer.cpp" line="135"/>
         <source>Press any key to close</source>
         <translation>Tryck på valfri tangent för att stänga</translation>
     </message>
@@ -100,4 +98,4 @@
         <translation>Du måste köra det här programmet som vanlig användare.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
